The GenTxt Sample Application

# The GenTxt General Analyzer

GenTxt is not currently supported. It is superseded by TAIParse, which is available at

http://www.textanalysis.com/Apps/POS_Tagger/pos_tagger.html

An older version, which includes a semantic analysis framework, is also available at

http://www.textanalysis.com/Apps/Natural_Language_Processing/natural_language_processing.html

A knowledge base that embeds WordNet is also available on request.